@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# pyramid_ldap documentation build configuration file
+# pyramid_ldap3 documentation build configuration file
 #
 # This file is execfile()d with the current directory set to its containing
 # dir.
@@ -19,7 +19,25 @@
 
 import sys, os
 
-import pylons_sphinx_themes
+# Add and use Pyramid theme
+if 'sphinx-build' in ' '.join(sys.argv): # protect against dumb importers
+    from subprocess import call, Popen, PIPE
+
+    p = Popen('which git', shell=True, stdout=PIPE)
+    git = p.stdout.read().strip()
+    cwd = os.getcwd()
+    _themes = os.path.join(cwd, '_themes')
+
+    if not os.path.isdir(_themes):
+        call([git, 'clone', 'git://github.com/Pylons/pylons_sphinx_theme.git',
+                '_themes'])
+    else:
+        os.chdir(_themes)
+        call([git, 'checkout', 'master'])
+        call([git, 'pull'])
+        os.chdir(cwd)
+
+    sys.path.append(os.path.abspath('_themes'))
 
 # General configuration
 # ---------------------
@@ -40,14 +58,14 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General substitutions.
-project = 'pyramid_ldap'
-copyright = '2017, Agendaless Consulting <chrism@plope.com>'
+project = 'pyramid_ldap3'
+copyright = '2012, Agendaless Consulting <chrism@plope.com>'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '0.3'
+version = '0.2'
 # The full version, including alpha/beta/rc tags.
 release = version
 
@@ -57,6 +75,9 @@ release = version
 # Else, today_fmt is used as the format for a strftime call.
 today_fmt = '%B %d, %Y'
 
+# Default domain for the project.
+primary_domain = 'py'
+
 # List of documents that shouldn't be included in the build.
 #unused_docs = []
 
@@ -88,12 +109,12 @@ pygments_style = 'sphinx'
 # Options for HTML output
 # -----------------------
 
-# Add and use pylons-sphinx-themes theme
+# Add and use Pylons theme
+sys.path.append(os.path.abspath('_themes'))
+html_theme_path = ['_themes']
 html_theme = 'pyramid'
-html_theme_path = pylons_sphinx_themes.get_html_themes_path()
-html_theme_options = dict(github_url='https://github.com/Pylons/pyramid_ldap',
-                          canonical_url='http://the_root_domain/latest/docs/',
-)
+html_theme_options = dict(github_url='https://github.com/Cito/pyramid_ldap3')
+
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
@@ -175,9 +196,8 @@ htmlhelp_basename = 'atemplatedoc'
 # (source start file, target name, title,
 #  author, document class [howto/manual]).
 latex_documents = [
-  ('index', 'pyramid_ldap.tex', 'pyramid_ldap Documentation',
-   'Repoze Developers', 'manual'),
-]
+    ('index', 'pyramid_ldap3.tex', 'pyramid_ldap3 Documentation',
+        'Repoze Developers', 'manual')]
 
 # The name of an image file (relative to this directory) to place at the
 # top of the title page.
