@@ -87,7 +87,8 @@ class _LDAPQuery(object):
             else:
                 result = [(r['dn'], r['attributes']) for r in result
                           if 'dn' in r]
-                self.cache[cache_key] = result
+                if self.cache_period:
+                    self.cache[cache_key] = result
         else:
             logger.debug('result for %r retrieved from cache', cache_key)
 
@@ -191,13 +192,13 @@ class Connector(object):
         if password == '':
             return None
 
-        conn = self.manager.connection()
         search = getattr(self.registry, 'ldap_login_query', None)
         if search is None:
             raise ConfigurationError(
                 'ldap_set_login_query was not called during setup')
 
-        result = search.execute(conn, login=login, password=password)
+        with self.manager.connection() as conn:
+            result = search.execute(conn, login=login, password=password)
 
         if not result or len(result) > 1:
             return None
@@ -230,18 +231,18 @@ class Connector(object):
         :exc:`pyramid.exceptions.ConfiguratorError`
 
         """
-        conn = self.manager.connection()
         search = getattr(self.registry, 'ldap_groups_query', None)
         if search is None:
             raise ConfigurationError(
                 'set_ldap_groups_query was not called during setup')
-        try:
-            result = search.execute(conn, userdn=escape_for_search(userdn))
-        except ldap3.LDAPException:
-            logger.debug(
-                'Exception in user_groups with userdn %r', userdn,
-                exc_info=True)
-            return None
+        with self.manager.connection() as conn:
+            try:
+                result = search.execute(conn, userdn=escape_for_search(userdn))
+            except ldap3.LDAPException:
+                logger.debug(
+                    'Exception in user_groups with userdn %r', userdn,
+                    exc_info=True)
+                return None
 
         return result
 
@@ -368,7 +369,7 @@ def get_ldap_connector(request):
     if connector is None:
         if ldap3.LDAPException is Exception:  # pragma: no cover
             raise ImportError(
-                'You must install python3-ldap to use an LDAP connector.')
+                'You must install ldap3 to use an LDAP connector.')
         raise ConfigurationError(
             'You must call Configurator.ldap_setup during setup '
             'to use an LDAP connector.')
